api

package
v0.0.0-...-8fb15e6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 14, 2026 License: GPL-3.0 Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DirectStream

func DirectStream(c *echo.Context) error

@Summary Direct video

@Description Retrieve the raw video stream, in the same container as the one on the server. @Description No transcoding or transmuxing is done.

@Tags streams @Param path path string true "Base64 of a video's path" format(base64) example(L3ZpZGVvL2J1YmJsZS5ta3YK) @Param identifier path string false "anything, this can be used for the automatic file name when downloading from the browser" example(bubble.mkv)

@Success 206 file "Video file (supports byte-requests)" @Router /:path/direct [get]

func RegisterHealthHandlers

func RegisterHealthHandlers(e *echo.Group, db *pgxpool.Pool)

func RegisterMetadataHandlers

func RegisterMetadataHandlers(e *echo.Group, metadata *src.MetadataService)

func RegisterPProfHandlers

func RegisterPProfHandlers(e *echo.Echo)

func RegisterStreamHandlers

func RegisterStreamHandlers(e *echo.Group, transcoder *src.Transcoder)

Types

This section is empty.

Jump to